@@ -27,9 +27,7 @@ ini_set('include_path',
 	dirname(__FILE__) . '/lib'
 	. PATH_SEPARATOR . ini_get('include_path')
 );
-
-// eh why not
-require 'Minify/HTML.php';
+include_once(dirname(__FILE__)."/necho.php");
 require 'Minify/CSS.php';
 require 'Minify/Javascript.php';
 class ScriptDeploy extends CMSModule
@@ -41,7 +39,7 @@ class ScriptDeploy extends CMSModule
 		return $this->Lang('friendlyname');
 	}
 	function GetVersion(){
-		return '0.4';
+		return '0.5';
 	}
 	function GetHelp(){
 		return $this->Lang('help');
@@ -62,13 +60,13 @@ class ScriptDeploy extends CMSModule
 		return true;
 	}
 	function GetAdminSection(){
-		return 'extensions';
+		return 'layout';
 	}
 	function GetAdminDescription(){
 		return $this->Lang('moddescription');
 	}
 	function VisibleToAdminUser(){
-		return $this->CheckPermission('Modify Calendar');
+		return $this->CheckPermission('Modify Site Preferences');
 	}
 	function GetDependencies(){
 		return array();
@@ -149,7 +147,7 @@ class ScriptDeploy extends CMSModule
 				}
 			}
 		}
-		if($scriptType!=''){
+		if(isset($scriptType)&&$scriptType!=''){
 			$type=$scriptType;
 		}
 		if($smartyOn==1){
@@ -344,8 +342,8 @@ class ScriptDeploy extends CMSModule
 				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_groupassignment AS sdGm ON sdG.ID = sdGm.GrouptSetID '
 				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_scriptoptions AS so ON so.ID = sdGm.ScriptID '
 				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_scriptnames AS sn ON so.ID = sn.ID '
-				.'WHERE sdG.ID = '.$scriptID.'';
-			$result = $db->Execute($query);
+				.'WHERE sdG.ID = ? ORDER BY sdGm.ScriptORDER ASC';
+			$result = $db->Execute($query,array($scriptID));
 			
 			while ($result && !$result->EOF){
 				$daKey=$result->fields['ScriptID'];
@@ -437,6 +435,33 @@ class ScriptDeploy extends CMSModule
 	}
 	
 
+
+
+function GetGroupID($groupName){
+			global $gCms;
+			$db =& $this->GetDb();
+			$query = 'SELECT ID FROM '.cms_db_prefix().'module_scriptdeploy_group '
+				.'WHERE GrouptSet=?';
+			$result = &$db->Execute($query,array($groupName));
+			while ($result && !$result->EOF){
+				$results=$result->fields['ID'];
+				$result->MoveNext();
+			}
+			return $results;		
+}
+function GetGroupName($gID){
+			global $gCms;
+			$db =& $this->GetDb();
+			$query = 'SELECT GrouptSet FROM '.cms_db_prefix().'module_scriptdeploy_group '
+				.'WHERE ID=?';
+			$result = &$db->Execute($query,array($gID));
+			while ($result && !$result->EOF){
+				$results=$result->fields['GrouptSet'];
+				$result->MoveNext();
+			}
+			return $results;		
+}
+
 /*----Get-the-set-of-the-file-------------------------*/
 	
 	function SizeItUp($size){
@@ -572,7 +597,7 @@ class ScriptDeploy extends CMSModule
 				$this->FireDebug('error',$key);//<<<<------Fire PHP message
 			$row = new StdClass();
 			$row->name = $this->CreateLink( $id, 'editassignment', $returnid,
-							$key, array('GrouptSet' => $key,
+							$key, array('GrouptID' => $key,
 									'active_tab' => $active_tab,
 									'mode'=>'edit'));
 			
@@ -583,7 +608,7 @@ class ScriptDeploy extends CMSModule
 			}
 			
 			$row->default = $this->CreateLink( $id, 'editassignment', $returnid,
-							$GrouptSet, array('GrouptSet' => $key,
+							$GrouptSet, array('GrouptID' => $key,
 									'active_tab' => $active_tab,
 									'mode'=>'edit'));
 			$row->Btn = $key;
@@ -595,7 +620,7 @@ class ScriptDeploy extends CMSModule
 								$gCms->variables['admintheme']->
 								DisplayImage ('icons/system/edit.gif',
 									  $this->Lang ('edit'), '', '', 'systemicon'),
-								array ('GrouptSet' => $key,
+								array ('GrouptID' => $key,
 								   'active_tab' => $active_tab,
 								   'mode'=>'edit'));
 			
